@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Mojolicious::Plugin::Web::Auth::Site::LinkedIn;
-$Mojolicious::Plugin::Web::Auth::Site::LinkedIn::VERSION = '0.04';
+$Mojolicious::Plugin::Web::Auth::Site::LinkedIn::VERSION = '0.05';
 use Mojo::Base qw/Mojolicious::Plugin::Web::Auth::OAuth2/;
 
 has access_token_url => 'https://www.linkedin.com/oauth/v2/accessToken';
@@ -11,6 +11,7 @@ has response_type    => 'code';
 has scope            => 'r_liteprofile r_emailaddress';
 has user_info        => 1;
 has user_info_url    => 'https://api.linkedin.com/v2/emailAddress?q=members&projection=(elements*(handle~))';
+has user_more_info_url => 'https://api.linkedin.com/v2/me?projection=(id,firstName,lastName,profilePicture(displayImage~:playableStreams))';
 has authorize_header => 'Bearer';
 
 sub moniker {'linkedin'}
@@ -27,7 +28,7 @@ Mojolicious::Plugin::Web::Auth::Site::LinkedIn - LinkedIn OAuth Plugin for Mojol
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -65,6 +66,8 @@ version 0.04
 This module adds L<LinkedIn|https://developer.linkedin.com/docs/rest-api/> support to
 L<Mojolicious::Plugin::Web::Auth>.
 
+The only extra URL option is the C<user_more_info_url> which the user can use to do a L<Mojo::UserAgent> call to with the access token as a parameter, to get the other info such as profile image and first or last name. This URL can also be modified by the user to retrieve extra fields. For more details refer to the L<LinkedIn API|https://developer.linkedin.com/docs/rest-api/>.
+
 =head1 AUTHOR
 
 Vikas N Kumar <vikas@cpan.org>
